mix firmware.push (nerves_firmware_ssh v0.4.4)

Upgrades the firmware on a Nerves device using SSH.

Please use mix firmware.gen.script and run the shell script until mix firmware.push can be properly fixed.

Summary

Functions

Callback implementation for Mix.Task.run/1.

Functions

run(args)

@spec run(keyword()) :: no_return()

Callback implementation for Mix.Task.run/1.